[Telepathy-commits] [telepathy-glib/master] Replace the remaining instances of the "channel factory" terminology

Simon McVittie simon.mcvittie at collabora.co.uk
Wed Jan 7 08:06:18 PST 2009


---
 examples/cm/echo-message-parts/chan.c       |    2 +-
 examples/cm/echo-message-parts/im-manager.c |    4 ++--
 examples/cm/echo-message-parts/im-manager.h |    7 +++----
 examples/cm/echo/chan.c                     |    2 +-
 4 files changed, 7 insertions(+), 8 deletions(-)

diff --git a/examples/cm/echo-message-parts/chan.c b/examples/cm/echo-message-parts/chan.c
index a581d56..0f2502d 100644
--- a/examples/cm/echo-message-parts/chan.c
+++ b/examples/cm/echo-message-parts/chan.c
@@ -480,7 +480,7 @@ example_echo_2_channel_close (ExampleEcho2Channel *self)
     {
       TpHandle first_sender;
 
-      /* The factory wants to be able to respawn the channel if it has pending
+      /* The manager wants to be able to respawn the channel if it has pending
        * messages. When respawned, the channel must have the initiator set
        * to the contact who sent us those messages (if it isn't already),
        * and the messages must be marked as having been rescued so they
diff --git a/examples/cm/echo-message-parts/im-manager.h b/examples/cm/echo-message-parts/im-manager.h
index 93bcced..28cfef9 100644
--- a/examples/cm/echo-message-parts/im-manager.h
+++ b/examples/cm/echo-message-parts/im-manager.h
@@ -1,5 +1,5 @@
 /*
- * factory.h - header for an example channel factory
+ * manager.h - header for an example channel manager
  *
  * Copyright (C) 2007 Collabora Ltd. <http://www.collabora.co.uk/>
  * Copyright (C) 2007 Nokia Corporation
@@ -9,11 +9,10 @@
  * notice and this notice are preserved.
  */
 
-#ifndef EXAMPLE_ECHO_MESSAGE_PARTS_FACTORY_H
-#define EXAMPLE_ECHO_MESSAGE_PARTS_FACTORY_H
+#ifndef EXAMPLE_ECHO_MESSAGE_PARTS_IM_MANAGER_H
+#define EXAMPLE_ECHO_MESSAGE_PARTS_IM_MANAGER_H
 
 #include <glib-object.h>
-#include <telepathy-glib/channel-factory-iface.h>
 
 G_BEGIN_DECLS
 
diff --git a/examples/cm/echo/chan.c b/examples/cm/echo/chan.c
index 2616b32..63050e0 100644
--- a/examples/cm/echo/chan.c
+++ b/examples/cm/echo/chan.c
@@ -366,7 +366,7 @@ example_echo_channel_close (ExampleEchoChannel *self)
     {
       TpHandle first_sender;
 
-      /* The factory wants to be able to respawn the channel if it has pending
+      /* The manager wants to be able to respawn the channel if it has pending
        * messages. When respawned, the channel must have the initiator set
        * to the contact who sent us those messages (if it isn't already),
        * and the messages must be marked as having been rescued so they
diff --git a/examples/cm/echo-message-parts/im-manager.c b/examples/cm/echo-message-parts/im-manager.c
index d8a88b0..1d5101c 100644
--- a/examples/cm/echo-message-parts/im-manager.c
+++ b/examples/cm/echo-message-parts/im-manager.c
@@ -101,7 +101,7 @@ set_property (GObject *object,
     {
     case PROP_CONNECTION:
       /* We don't ref the connection, because it owns a reference to the
        * factory, and it guarantees that the factory's lifetime is
        * less than its lifetime */
       self->priv->conn = g_value_get_object (value);
       break;
@@ -148,7 +148,7 @@ example_echo_2_im_manager_class_init (ExampleEcho2ImManagerClass *klass)
   object_class->set_property = set_property;
 
   param_spec = g_param_spec_object ("connection", "Connection object",
-      "The connection that owns this channel factory",
+      "The connection that owns this channel manager",
       TP_TYPE_BASE_CONNECTION,
       G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE |
       G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB);
@@ -101,7 +101,7 @@ set_property (GObject *object,
     case PROP_CONNECTION:
       /* We don't ref the connection, because it owns a reference to the
-       * factory, and it guarantees that the factory's lifetime is
+       * channel manager, and it guarantees that the manager's lifetime is
        * less than its lifetime */
       self->priv->conn = g_value_get_object (value);
-- 
1.5.6.5




More information about the Telepathy-commits mailing list